capture log close
if(${logfile}==1) log using "${log}/09a_impute_missings.log", replace

*______________________________________________________________________________
*
* 09a_impute_missings.do		
*
* Author: Michelle Hansch
*
* Imputation of missing occupation, sector, and region/district of work from
* previous/following non-missing values if the individual worked within the same
* establishment. 
*
* Notes: 
* Up until 2011, employers still reported their employees' occupations using 
* the 1988 classification. They officially switched to the new classification 
* from December 2011 onward. During the transition period in 2011 and 2012, 
* employers were granted time to adjust their reporting scheme to the new 
* classification, resulting in significant gaps in occupational information 
* (Bertat et al., 2013). 
* As the data includes parallel spells at this point, we need the previously 
* defined spell variable as unambiguous identifier (only unambiguous for 
* employment spells).					
*								
*______________________________________________________________________________


gen missing_orig=0
foreach var of varlist beruf beruf2010_4 niveau ao_bula ao_kreis w93_3_gen {
	replace `var'=. if missing(`var')==1
	replace missing_orig=1 if `var'==. & quelle==1
}

* How many missing observations do we have?
tab jahr missing_orig if quelle==1, m
tab jahr missing_orig if quelle==1 & east==0, m // only West Germany

* Check for duplicates in the sorting criteria
duplicates tag persnr betnr spell, gen(dupl)
tab dupl if quelle==1, m // no duplicates for employment spells
drop dupl

* Impute missing value from individual's previous/next spell if he/she worked in the same establishment 
gen missing_intermediate=0
foreach var of varlist beruf beruf2010_4 niveau ao_bula ao_kreis w93_3_gen teilzeit {
	sort persnr betnr spell
	replace `var'=`var'[_n-1] if `var'==. & `var'[_n-1]!=. & persnr==persnr[_n-1] & betnr==betnr[_n-1] & quelle==1 & quelle[_n-1]==1
	gsort persnr betnr -spell
	replace `var'=`var'[_n-1] if `var'==. & `var'[_n-1]!=. & persnr==persnr[_n-1] & betnr==betnr[_n-1] & quelle==1 & quelle[_n-1]==1
	replace missing_intermediate=1 if `var'==. & quelle==1
}

* How many missing observations are left?
tab jahr missing_intermediate if quelle==1, m
tab jahr missing_intermediate if quelle==1 & east==0, m  // only West Germany

* Impute missing work district/region and sector codes from nonmissing values of coworkers in the same year (if available)
/* Sometimes ambiguous observations, i.e., different industries/regions for the same establishment/year  -> assign the most frequently occurring value (mode). */
gen missing_final=0
foreach var of varlist ao_bula ao_kreis w93_3_gen {
	* Extract nonmissing information from same year, same establishment 
	bysort betnr jahr: egen `var'_mode=mode(`var') if quelle==1, minmode // returns the value of `var' occurring most frequently for each establishment/year combination
    * Update missing variable
	replace `var'=`var'_mode if `var'==. & `var'_mode!=. & quelle==1
	drop `var'_mode
	replace missing_final=1 if `var'==. & quelle==1
}

* How many missing observations are left?
tab jahr missing_final if quelle==1, m
tab missing_orig missing_final if quelle==1, m

* Update east variable with new ao_bula information
replace east = 1 if inlist(ao_bula, 11, 12, 13, 14, 15, 16)	& east==. & quelle==1	// East: Berlin, Brandenburg, Mecklenburg-Western Pomerania, Saxony, Saxony-Anhalt, Thuringia
replace east = 0 if ao_bula < 11 & east==. & quelle==1								// West: Schleswig-Holstein, Hamburg, Lower Saxony, Bremen, North Rhine-Westphalia, Hesse, Rhineland-Palatinate, Baden-Wuerttemberg, Bavaria, Saarland
replace east = 0 if ao_bula == 11 & jahr < 1992 & quelle==1		
tab ao_bula east if quelle==1, m

* Create 5-digit KldB2010
gen beruf2010_5=string(beruf2010_4,"%2.0f")+string(niveau,"%2.0f")
destring beruf2010_5, replace force

* Drop if KldB 2010 occupation variable missing after 2010 
drop if beruf2010_5==. & jahr>2010 & quelle==1

* Resort the data
sort persnr spell

cap log close
