cap log close
if(${logfile}==1) log using "${log}/09b_restrictions.log", replace


/*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	
	SIAB Preparation
	
	Restricts the data to certain groups
	
	On default most commands are commented out. Users should uncomment and adjust selected lines.
	
	
	Author(s): Wolfgang Dauth, Johann Eppelsheimer, Heiko Stüber

	Version: 1.0
	Created: 2022-11-24
	
	Comment: 
	Users can also run this do-file on the finished clean_siab.dta.

	Note: 
	This do-file is part of the Stata do-file collection offered as a 
	supplement to Stüber, Dauth, and Eppelsheimer (2023): A Guide to Preparing 
	the Sample of Integrated Labour Market Biographies (SIAB, version 7519 v1) 
	for Scientific Analysis. Journal for Labour Market Research, 57:7.
	https://doi.org/10.1186/s12651-023-00335-w
	
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~*/


********************************************************************************
* Data source
********************************************************************************
if(${inspect}==1) tab quelle, m

keep if quelle == 1		// BeH  (Employee History)
* keep if quelle == 2		// LEH  (Benefit Recipient History)
* keep if quelle == 3		// LHG  (Unemployment Benefit II Recipient History)


********************************************************************************
* Years
********************************************************************************
if(${inspect}==1) su jahr

* keep if inrange(jahr,1975,2019) // keep data of years 1975 to 2019


********************************************************************************
* Keep only spells that exist on June 30
********************************************************************************
keep if inrange(mdy(6,30,jahr),begepi,endepi) // only keep spells that exist over the cutoff date (June 30);  inrange(mdy(month,year,jahr),begepi,endepi)


********************************************************************************
* Age limits
********************************************************************************
if(${inspect}==1) sum age
keep if inrange(age,25,54) // keep spells of individuals aged 25 to 54 (default: 18 to 65)


********************************************************************************
* Male/female
********************************************************************************
if(${inspect}==1) tab frau, m
drop if missing(frau)	// drop missings

* keep if frau == 1	// keep women only
* keep if frau == 0	// keep men only



********************************************************************************
* Occupational status
********************************************************************************
if(${inspect}==1) tab erwstat, m

keep if inlist(erwstat, 101, 140, 143)		// only keep employees liable to social security ("Sozialversicherungspflichtig Beschaeftigte")  

* drop if erwstat < 100					// drop if not in employment
* drop if missing(erwstat)				// drop if missing employment status
* drop if inlist(erwstat, 102, 121, 122, 141)		// drop trainees
* drop if inlist(erwstat, 109, 209)			// drop marginal part-time workers
* drop if inlist(erwstat, 105, 106)			// drop interns/trainees
* drop if inlist(erwstat, 140, 141, 142, 143, 149)	// drop sailors
* drop if inlist(erwstat, 123)				// drop voluntary social/ecological year, ...
* drop if inlist(erwstat, 103, 119, 120, 149)		// drop partial retirement
* drop if inlist(erwstat, 112)				// drop family member workers in agriculture
* drop if inlist(erwstat, 203)				// drop artists
* drop if inlist(erwstat, 118, 205)			// drop casual workers
* drop if inlist(erwstat, 201)				// drop employees registered within households
* drop if inlist(erwstat, 104, 142)			// drop other groups with less than 100 workers
* drop if inlist(erwstat, 124)				// drop home workers
* drop if inlist(erwstat, 599)				// drop others


********************************************************************************
* Occupations
********************************************************************************
if(${inspect}==1) tab beruf, m
if(${inspect}==1) tab beruf2010_5/*beruf2010_3*/, m

* Drop certain occupational categories 
//drop if beruf==531 // Assistants (no further specification)
drop if beruf==555 // Disabled persons
drop if beruf==666 // Rehabilitants
//drop if beruf==971 // Non-agricultural family assistants, n.e.c.
drop if beruf==981 // Trainees with recognised training occupation still to be specified
drop if beruf==982 // Interns, unpaid trainees with recognised training occupation still to be specified
drop if beruf==983 // Workforce (job seekers) with occupation still to be specified
drop if beruf==991 // Workforce not further specified
drop if beruf==995 // Recipients of early retirement pension
drop if beruf==996 // Employees in partial retirement
drop if beruf==997 // Recipients of compensations allowance



********************************************************************************
* Full-time
********************************************************************************
if(${inspect}==1) tab teilzeit, m
drop if missing(teilzeit)==1 & quelle==1 // drop if we have no information on part-time or full-time work (needed for part-time correction)

* keep if teilzeit == 0	// keep only full-time workers
* keep if teilzeit == 1 // keep only part-time workers 

********************************************************************************
* Wages below marginal part-time income threshold ("Geringfuegigkeitsgrenze")
********************************************************************************
if(${inspect}==1) sum tentgelt
if(${inspect}==1) tab marginal, m

drop if marginal == 1 & quelle == 1 // drop marginal part-time workers


********************************************************************************
* Missing establishment identifier
********************************************************************************
if(${inspect}==1) count if missing(betnr) & quelle == 1
drop if missing(betnr) & quelle == 1

/*
	Comment:
	
	The variables betnr refers to the workplace of individuals.
	Hence, people not in employment have missings in this variable!
*/


********************************************************************************
* Missing regional information of WORKPLACE
********************************************************************************
if(${inspect}==1) count if missing(ao_bula) & quelle == 1
drop if missing(ao_bula) & quelle == 1

/*
	Comment:
	
	The variables ao_bula refers to the workplace of individuals.
	Hence, people not in employment have missings in this variable!
*/


********************************************************************************
* WORKPLACE in East/West
********************************************************************************
if(${inspect}==1) tab ao_bula east, m
drop if missing(east) & quelle == 1

tab ao_bula east if jahr==1991, m

drop if ao_bula == 11 & jahr < 1992 & quelle==1 // exclude (West) Berlin before 1992 for the sake of consistency (was assigned to West Germany but only until 1991)	

tab ao_bula east, m
tab jahr east, m

* keep if east == 0		 // workplace in West (incl. Berlin until 1991) (drops all non-working individuals!)
* keep if ao_bula <= 10		 // workplace in West (excl. Berlin) (drops all non-working individuals!)
* keep if east == 1 		 // workplace in East (incl. Berlin) from 1992 onward (drops all non-working individuals!)
* keep if inrange(ao_bula,12,16) // workplace in East (excl. Berlin) (drops all non-working individuals!)

/* 
	Comment:
	
	east = 1: workplace in East Germany from 1992 onward (incl. Berlin)
	east = 0: workplace in West Germany until 1991 including Berlin, from 1992 onward excl. Berlin

	For further details see ao_bula (from BHP).
	
	The variables east and ao_bula refer to the workplace of individuals.
	Hence, people not in employment have missings in these variables!
*/


********************************************************************************
* Other restrictions
********************************************************************************
drop if tentgelt == 0 & quelle == 1 // drop employment spells with wage of 0 €

* Remove all variables that contain only missings
foreach var of varlist _all {
	capture assert missing(`var')
	if !_rc {
		drop `var'
	}
}


cap log close
