cap log close
if(${logfile}==1) log using "${log}/15_parallel_episodes.log", replace


/*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	
	SIAB Preparation
	
	Treat parallel episodes: 
		- generate some information on parallel episodes
		- keep only 'main' episode
		
	Generates the variables:
		- nspell: non-parallel spell counter
		- parallel_jobs: number of parallel jobs
		- parallel_wage: total wage of all parallel employment spells
		- parallel_wage_imp: total imputed wage of all parallel employment spells
		- parallel_benefits: indicator for recipience of UI benefits
		
	Drops the variables:
		- spell
		- level1
		- level2
		
	
	Author(s): Wolfgang Dauth, Johann Eppelsheimer, Heiko Stüber

	Version: 1.0
	Created: 2022-11-24

	Note: 
	This do-file is part of the Stata do-file collection offered as a 
	supplement to Stüber, Dauth, and Eppelsheimer (2023): A Guide to Preparing 
	the Sample of Integrated Labour Market Biographies (SIAB, version 7519 v1) 
	for Scientific Analysis. Journal for Labour Market Research, 57:7.
	https://doi.org/10.1186/s12651-023-00335-w
	
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~*/


********************************************************************************
* Identify main episode (by sorting data accordingly)
********************************************************************************

/*
	Comment: 
	
	There is no common rule of identifying the main episode. Usually the job
	with the longest duration or the highest wage is defined as the main episode.
	However, it is left to the user to decide which characteristic defines the
	main episode.
	
*/

gsort persnr begepi quelle -tage_bet -wage_imp		// define job with longest tenure as main episode
* gsort persnr begepi quelle -wage_imp -tage_bet	// define job with highest wage as main episode
* Note: Be aware of the fact that the sorting needs to be unambiguous. If there are still duplicates in the variables used in the gsort command, it is strongly advisable to add variables in the sorting such that the order of the spells is unique. Otherwise, the keep condition “by persnr begepi: keep if _n == 1” at the end of this do-file will contain arbitrary sorting, such that the sample selection might differ when running the code again.


if $parallel_vars == 1 {
********************************************************************************
* Generate information on parallel jobs (parallel_jobs, parallel_wage, parallel_wage_imp)
********************************************************************************
gen tmp_jobs = quelle == 1 
gen tmp_wage = wage_defl/*tentgelt*/ if quelle == 1
gen tmp_wage_imp = wage_imp if quelle == 1 

by persnr begepi: egen parallel_jobs = total(tmp_jobs)			// count parallel employment episodes
by persnr begepi: egen parallel_wage = total(tmp_wage)			// total wage of all parallel employment episodes
by persnr begepi: egen parallel_wage_imp = total(tmp_wage_imp)	// total (imputed) wage of all parallel employment episodes

label language de
label variable parallel_jobs "Anzahl paralleler Spells"
label variable parallel_wage "Gesamtes Entgelt pro Episode"
label variable parallel_wage_imp "Gesamtes (imputiertes) Entgelt pro Episode"
label language en
label variable parallel_jobs "Number of parallel jobs"
label variable parallel_wage "Total wage per episode"
label variable parallel_wage_imp "Total (imputed) wage per episode"

********************************************************************************
* Generate information of possibly parallel UI benefits (parallel_benefits)
********************************************************************************
gen tmp_benefits = (quelle==2 | quelle==3)	// indicator for recipience of UI benefits
by persnr begepi: egen parallel_benefits = max(tmp_benefits)		// attach indicator for recipience of UI benefits to all parallel episodes
label language de
label variable parallel_benefits "Gesamtarbeitslosengeld pro Episode" 
label language en
label variable parallel_benefits "Total UI benefits per episode" 

drop tmp_jobs tmp_wage tmp_wage_imp tmp_benefits
}


********************************************************************************
********************************************************************************
********************************************************************************
* Designated area for (further) restrictions on the data set
********************************************************************************
/* 
Restrictions on the data set should only be implemented in the designated below, 
when you:
1) wish to generate the aggregated variables defined above (global parallel_vars = 1)
2) do not wish to generate the yearly panel using 16_yearly_panel.do

Note: please make sure to keep all variables that are needed to define the main 
episode.

When you wish to generate the yearly panel using 16_yearly_panel.do, implement 
restrictions in the designated are in 16_yearly_panel.do.

When you do not wish to generate the aggregated variables defined above 
(global parallel_vars = 1) and you do not wish to generate the yearly panel,
please implement all restrictions in 09_restrictions.do.
*/
********************************************************************************
********************************************************************************
********************************************************************************


********************************************************************************
* Occupational status
********************************************************************************
* tab erwstat, m

* keep if inlist(erwstat, 101, 140, 143)			// only keep employees liable to social security ("Sozialversicherungspflichtig Beschaeftigte")  

* drop if erwstat < 100								// drop if not in employment
* drop if missing(erwstat)							// drop if missing employment status
* drop if inlist(erwstat, 102, 121, 122, 141)		// drop trainees
* drop if inlist(erwstat, 109, 209)					// drop marginal part-time workers
* drop if inlist(erwstat, 105, 106)					// drop interns/trainees
* drop if inlist(erwstat, 140, 141, 142, 143, 149)	// drop sailors
* drop if inlist(erwstat, 123)						// drop voluntary social/ecological year, ...
* drop if inlist(erwstat, 103, 119, 120, 149)		// drop partial retirement
* drop if inlist(erwstat, 112)						// drop family member workers in agriculture
* drop if inlist(erwstat, 203)						// drop artists
* drop if inlist(erwstat, 118, 205)					// drop casual workers
* drop if inlist(erwstat, 201)						// drop employees registered within households
* drop if inlist(erwstat, 104, 142)					// drop other groups with less than 100 workers
* drop if inlist(erwstat, 124)						// drop home workers
* drop if inlist(erwstat, 599)						// drop others



********************************************************************************
* Occupations
********************************************************************************
* tab beruf, m
* tab beruf2010_3, m

* drop ...


********************************************************************************
* Full-time
********************************************************************************
* tab teilzeit, m

* keep if teilzeit == 0	// keep only full-time workers
* keep if teilzeit == 1 // keep only part-time workers 


********************************************************************************
* Wages below marginal part-time income threshold ("Geringfuegigkeitsgrenze")
********************************************************************************
* sum tentgelt
* tab marginal, m

* drop if marginal == 1 & quelle == 1 // drop marginal part-time workers


********************************************************************************
* Missing establishment identifier
********************************************************************************
* count if missing(betnr) & quelle == 1
* drop if missing(betnr) & quelle == 1

/*
	Comment:
	
	The variables betnr refers to the workplace of individuals.
	Hence, people not in employment have missings in this variable!
*/


********************************************************************************
* Missing regional information of WORKPLACE
********************************************************************************
* count if missing(ao_bula) & quelle == 1
* drop if missing(ao_bula) & quelle == 1

/*
	Comment:
	
	The variables ao_bula refers to the workplace of individuals.
	Hence, people not in employment have missings in this variable!
*/


********************************************************************************
* WORKPLACE in East/West
********************************************************************************
* tab ao_bula east, m

* drop if missing(east) & quelle == 1

* keep if east == 0						// workplace in West (incl. Berlin until 1991) (drops all non-working individuals!)
* keep if ao_bula <= 10					// workplace in West (excl. Berlin) (drops all non-working individuals!)
* keep if east == 1 					// workplace in East (incl. Berlin) from 1992 onward (drops all non-working individuals!)
* keep if inrange(ao_bula,12,16)		// workplace in East (excl. Berlin) (drops all non-working individuals!)

/* 
	Comment:
	
	east = 1: workplace in East Germany from 1992 onward (incl. Berlin)
	east = 0: workplace in West Germany until 1991 including Berlin, from 1992 onward excl. Berlin

	For further details see ao_bula (from BHP).
	
	The variables east and ao_bula refer to the workplace of individuals.
	Hence, people not in employment have missings in these variables!
*/


********************************************************************************
* Other restrictions
********************************************************************************
/*
* Remove all variables that contain only missings
foreach var of varlist _all {
	capture assert missing(`var')
	if !_rc {
		drop `var'
	}
}
*/


********************************************************************************
* Only keep the main episode
/*
* If you (re)sorted the data while restricting it, make soure to sort it again to
define the main episode correctly:
gsort persnr begepi quelle -tage_bet -wage_imp	// define job with longest tenure as main episode
gsort persnr begepi quelle -wage_imp -tage_bet	// define job with highest wage as main episode

* Note: Be aware of the fact that the sorting needs to be unambiguous. If there are still duplicates in the variables used in the gsort command, it is strongly advisable to add variables in the sorting such that the order of the spells is unique. Otherwise, the following keep condition will contain arbitrary sorting, such that the sample selection might differ when running the code again.
*/
********************************************************************************
by persnr begepi: keep if _n == 1


********************************************************************************
* Generate non-parallel spell counter
********************************************************************************
by persnr: gen nspell = _n
label language de
label variable nspell "Nicht-paralleler Spellzähler" 
label language en
label variable nspell "Non-parallel spell counter" 

********************************************************************************
* Clean up
********************************************************************************
sort persnr nspell
drop spell level1 level2


cap log close
