cap log close
if(${logfile}==1) log using "${log}/16_yearly_panel.log", replace


/*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	
	SIAB Preparation
	
	Transfer data set into yearly panel (using one specific cutoff date)
	 - retain information on total employment / unemployment durations and earnings per year
	
	Generates the variables:
		- year_days_emp: total days employed per calendar year
		- year_days_benefits: total days benefit recipience per calendar year
		- year_labor_earn: total labor earnings per calendar year
		
	Drops the variables:
		- nspell
		- begorig
		- endorig
		- begepi
		- endepi
		- begepi_orig
		- endepi_orig

		
	Author(s): Wolfgang Dauth, Johann Eppelsheimer, Heiko Stüber

	Version: 1.0
	Created: 2022-11-24

	Note: 
	This do-file is part of the Stata do-file collection offered as a 
	supplement to Stüber, Dauth, and Eppelsheimer (2023): A Guide to Preparing 
	the Sample of Integrated Labour Market Biographies (SIAB, version 7519 v1) 
	for Scientific Analysis. Journal for Labour Market Research, 57:7.
	https://doi.org/10.1186/s12651-023-00335-w
	
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~*/


if $yearly_vars == 1 {
********************************************************************************
* Aggregate (employment) outcomes: days employed, labor earnings, days benefits
********************************************************************************
*Durations of episodes
sort persnr jahr begepi endepi quelle
by persnr jahr begepi endepi: gen dur_emp = endepi-begepi + 1 if quelle == 1
by persnr jahr begepi endepi: gen dur_benefits = endepi-begepi + 1 if quelle == 2 | parallel_benefits == 1

*Total time working, total time receiving UI benefits
by persnr jahr: egen year_days_emp=total(dur_emp)
by persnr jahr: egen year_days_benefits=total(dur_benefits)

*Earnings=wage*duration
gen help_labor_earn=parallel_wage_imp*dur_emp
by persnr jahr: egen year_labor_earn=total(help_labor_earn)
drop dur_emp dur_benefits help_labor_earn

label language de
lab var year_days_emp "Gesamtzahl der Arbeitstage pro Kalenderjahr"
lab var year_days_benefits "Gesamtzahl der Tage des Leistungsbezugs pro Kalenderjahr"
lab var year_labor_earn "Gesamtes Entgelt pro Kalenderjahr"

label language en
lab var year_days_emp "Total days employed per calendar year"
lab var year_days_benefits "Total days benefit recipience per calendar year"
lab var year_labor_earn "Total labor earnings per calendar year"
}


********************************************************************************
* Keep only episodes that exist over the cutoff date as set in master.do
********************************************************************************
keep if inrange(mdy(${cutoffMonth},${cutoffDay},jahr),begepi,endepi)


********************************************************************************
* Adjust durations to end at cutoff date
********************************************************************************
foreach var of varlist tage_bet tage_job { 
	replace `var' = `var' - (endepi - mdy($cutoffMonth, $cutoffDay, jahr)) if quelle == 1
}

replace tage_erw = tage_erw - (endepi - mdy($cutoffMonth, $cutoffDay, jahr)) if quelle == 1 & !inlist(erwstat, 102, 121, 122, 141, 144)	// excluding Azubis
replace tage_lst = tage_lst - (endepi - mdy($cutoffMonth, $cutoffDay, jahr)) if inlist(quelle, 2, 3/*16*/) // | parallel_benefits == 1
if $parallel_vars == 1 {
replace tage_lst = tage_lst - (endepi - mdy($cutoffMonth, $cutoffDay, jahr)) if parallel_benefits == 1 // inlist(quelle, 2, 16) | 
}
		
********************************************************************************
* Clean up
********************************************************************************
drop nspell begorig endorig //begepi endepi begepi_orig endepi_orig



********************************************************************************
********************************************************************************
********************************************************************************
* Designated area for (further) restrictions on the data set
********************************************************************************
/* 
Restrictions on the data set should only be implemented in the designated below, 
when you wish to:
1) generate the aggregated variables defined above (global yearly_vars = 0)
2) generate the yearly panel using 16_yearly_panel.do

Otherwise please implement all restrictions in 15_parallel_episodes.do (see note 
there) or in 09_restrictions.do.
*/
********************************************************************************
********************************************************************************
********************************************************************************


********************************************************************************
* Occupational status
********************************************************************************
* tab erwstat, m

* keep if inlist(erwstat, 101, 140, 143)			// only keep employees liable to social security ("Sozialversicherungspflichtig Beschaeftigte")  

* drop if erwstat < 100								// drop if not in employment
* drop if missing(erwstat)							// drop if missing employment status
* drop if inlist(erwstat, 102, 121, 122, 141)		// drop trainees
* drop if inlist(erwstat, 109, 209)					// drop marginal part-time workers
* drop if inlist(erwstat, 105, 106)					// drop interns/trainees
* drop if inlist(erwstat, 140, 141, 142, 143, 149)	// drop sailors
* drop if inlist(erwstat, 123)						// drop voluntary social/ecological year, ...
* drop if inlist(erwstat, 103, 119, 120, 149)		// drop partial retirement
* drop if inlist(erwstat, 112)						// drop family member workers in agriculture
* drop if inlist(erwstat, 203)						// drop artists
* drop if inlist(erwstat, 118, 205)					// drop casual workers
* drop if inlist(erwstat, 201)						// drop employees registered within households
* drop if inlist(erwstat, 104, 142)					// drop other groups with less than 100 workers
* drop if inlist(erwstat, 124)						// drop home workers
* drop if inlist(erwstat, 599)						// drop others


********************************************************************************
* Occupations
********************************************************************************
* tab beruf, m
* tab beruf2010_3, m

* drop ...


********************************************************************************
* Full-time
********************************************************************************
* tab teilzeit, m

* keep if teilzeit == 0	// keep only full-time workers
* keep if teilzeit == 1 // keep only part-time workers 


********************************************************************************
* Wages below marginal part-time income threshold ("Geringfuegigkeitsgrenze")
********************************************************************************
* sum tentgelt
* tab marginal, m

* drop if marginal == 1 & quelle == 1 // drop marginal part-time workers


********************************************************************************
* Missing establishment identifier
********************************************************************************
* count if missing(betnr) & quelle == 1

* drop if missing(betnr) & quelle == 1

/*
	Comment:
	
	The variables betnr refers to the workplace of individuals.
	Hence, people not in employment have missings in this variable!
*/


********************************************************************************
* Missing regional information of WORKPLACE
********************************************************************************
* count if missing(ao_bula) & quelle == 1

* drop if missing(ao_bula) & quelle == 1

/*
	Comment:
	
	The variables ao_bula refers to the workplace of individuals.
	Hence, people not in employment have missings in this variable!
*/


********************************************************************************
* WORKPLACE in East/West
********************************************************************************
* tab ao_bula east, m

* drop if missing(east) & quelle == 1

* keep if east == 0						// workplace in West (incl. Berlin until 1991) (drops all non-working individuals!)
* keep if ao_bula <= 10					// workplace in West (excl. Berlin) (drops all non-working individuals!)
* keep if east == 1 					// workplace in East (incl. Berlin) from 1992 onward (drops all non-working individuals!)
* keep if inrange(ao_bula,12,16)		// workplace in East (excl. Berlin) (drops all non-working individuals!)

/* 
	Comment:
	
	east = 1: workplace in East Germany from 1992 onward (incl. Berlin)
	east = 0: workplace in West Germany until 1991 including Berlin, from 1992 onward excl. Berlin

	For further details see ao_bula (from BHP).
	
	The variables east and ao_bula refer to the workplace of individuals.
	Hence, people not in employment have missings in these variables!
*/


********************************************************************************
* Other restrictions
********************************************************************************
/*
* Remove all variables that contain only missings
foreach var of varlist _all {
	capture assert missing(`var')
	if !_rc {
		drop `var'
	}
}
*/


cap log close
