capture log close
log using "${log}/18b_parttime_correction_west.log", replace


********************************************************************************
* 18b_parttime_correction_west.do														
* Implements part-time correction procedure following Fitzenberger and			
* Seidlitz (2020).			
*
* Fitzenberger, Bernd, and Arnim Seidlitz. "The 2011 break in the part-time 
* indicator and the evolution of wage inequality in Germany." Journal for 
* Labour Market Research 54.1 (2020): 1-14.
*
* Create full-time equivalence weights:										
* - original part-time spells: 0.5												
* - full-time spells get a weight between 0 and 1 according to the predictions 	
*   from the Probit models implemented below (separately by gender, age groups 	
*   etc.)																		
********************************************************************************
use "${data}/siab_clean.dta", clear

* Intall carryforward package
//fdzinstall carryforward

* Only keep West Germany
*-----------------------
keep if east==0

* Exclude UI benefit recipients
*------------------------------
keep if quelle==1
tab quelle, m

*-----------------------------
* Create additional variables 
*-----------------------------

* Generate age squared
*---------------------
gen age2=age*age

* Create daily real wage variable (imputed): ln(wage)
*----------------------------------------------------
gen ln_wage_imp=ln(wage_imp)
label var ln_wage_imp "ln of avg. daily real wage of the main spell (imputed)"

* Create 10 occupation categories (berufcat) 
*-------------------------------------------
/* The reference group (berufcat=0) corresponds to missing values */
gen berufcat=0  // missing values
* 1 Agricultural occupations
replace berufcat=1 if beruf>=11 & beruf<=62
* 3 Mining, manufacturing occ. outside industry
replace berufcat=3 if beruf>=71 & beruf<=112
replace berufcat=3 if beruf>=121 & beruf<=549
* 2 Manufacturing occ. in industry, techn. occ. (ordering imporant here!)
replace berufcat=2 if beruf>=601 & beruf<=635
replace berufcat=2 if beruf>=121 & beruf<=549 & w93_3_gen>=201 & w93_3_gen<=372  
* 4 Service, trading goods
replace berufcat=4 if beruf>=681 & beruf<=688 
* 5 Service, other trading occ.
replace berufcat=5 if beruf>=691 & beruf<=706 
* 6 Service, traffic/logistics)
replace berufcat=6 if beruf>=711 & beruf<=744
* 7 Service, administration
replace berufcat=7 if beruf>=751 & beruf<=784
* 10 Service, other
replace berufcat=10 if beruf>=791  & beruf<=838  
replace berufcat=10 if beruf>=901 & beruf!=. 
* 8 Service, health sector
replace berufcat=8 if beruf>=841  & beruf<=856 
* 9 Service, education sector
replace berufcat=9 if beruf>=861  & beruf<=883
label def bec 	0 "0 Missings (reference category)" ///
		1 "1 Agricultural occ." ///
		2 "2 Manufacturing occ. in industry, techn. occ." ///
		3 "3 Mining, manufacturing occ. outside industry" ///
		4 "4 Service, trading goods" ///
		5 "5 Service, other trading occ." ///
		6 "6 Service, traffic/logistics)" ///
		7 "7 Service, administration" ///
		8 "8 Service, health sector" ///
		9 "9 Service, education sector" ///
		10 "10 Service, other"
label val berufcat bec
label var berufcat "Occupation categories for part-time correction procedure"
	
tab berufcat, m

* Generate 13 sector categories (w93)
*------------------------------------
/* The reference group (w93=0) corresponds to missing values */
gen w93=0  // missing values
replace w93=1 if w93_3_gen>=11 & w93_3_gen<=145 
replace w93=2 if w93_3_gen>=201 & w93_3_gen<=205 | w93_3_gen>=231 & w93_3_gen<=233 | w93_3_gen>=241 & w93_3_gen<=247 | w93_3_gen>=251 & w93_3_gen<=252 
replace w93=3 if w93_3_gen>=271 & w93_3_gen<=275 | w93_3_gen>=281 & w93_3_gen<=287 | w93_3_gen>=291 & w93_3_gen<=297
replace w93=4 if w93_3_gen>=300 & w93_3_gen<=316 | w93_3_gen>=321 & w93_3_gen<=323 | w93_3_gen>=331 & w93_3_gen<=335 | w93_3_gen>=341 & w93_3_gen<=343 | w93_3_gen>=351 & w93_3_gen<=355 
replace w93=5 if w93_3_gen>=151 & w93_3_gen<=160 | w93_3_gen>=171 & w93_3_gen<=177 | w93_3_gen>=181 & w93_3_gen<=183 | w93_3_gen>=191 & w93_3_gen<=193 | w93_3_gen>=211 & w93_3_gen<=212 | w93_3_gen>=221 & w93_3_gen<=223 | w93_3_gen>=261 & w93_3_gen<=268 | w93_3_gen>=361 & w93_3_gen<=366 | w93_3_gen>=371 & w93_3_gen<=372 
replace w93=6 if w93_3_gen>=551 & w93_3_gen<=555
replace w93=7 if w93_3_gen>=454 & w93_3_gen<=455
replace w93=8 if w93_3_gen>=501 & w93_3_gen<=505 | w93_3_gen>=511 & w93_3_gen<=517 | w93_3_gen>=521 & w93_3_gen<=527 
replace w93=9 if w93_3_gen>=601 & w93_3_gen<=603 | w93_3_gen>=611 & w93_3_gen<=612 | w93_3_gen>=621 & w93_3_gen<=623 | w93_3_gen>=631 & w93_3_gen<=634 | w93_3_gen>=641 & w93_3_gen<=642 
replace w93=10 if w93_3_gen>=651 & w93_3_gen<=652 | w93_3_gen==660 | w93_3_gen>=671 & w93_3_gen<=672 | w93_3_gen>=701 & w93_3_gen<=703 | w93_3_gen>=711 & w93_3_gen<=714 | w93_3_gen>=721 & w93_3_gen<=726 | w93_3_gen>=731 & w93_3_gen<=732 | w93_3_gen>=741 & w93_3_gen<=748
replace w93=11 if w93_3_gen>=401 & w93_3_gen<=403 | w93_3_gen==410 | w93_3_gen==900 | w93_3_gen>=911 & w93_3_gen<=913 | w93_3_gen>=921 & w93_3_gen<=927 | w93_3_gen==930 | w93_3_gen==950
replace w93=12 if w93_3_gen>=801 & w93_3_gen<=804 | w93_3_gen>=851 & w93_3_gen<=853 
replace w93=13 if w93_3_gen>=751 & w93_3_gen<=753 | w93_3_gen==990
* Labels
label def w93_de 0 "0 Missings (reference category)" ///
		1 "1 Agriculture, mining and quarrying" ///
		2 "2 Production of rubber/platic products, processing of minerals, wood and chemical industry" ///
		3 "3 Metal production and processing, mechanical engineering" ///
		4 "4 Automotive, production of data processing equipment, electrical and optical engineering" ///
		5 "5 consumer goods" ///
		6 "6 Hospitality industry" ///
		7 "7 Building industry" ///
		8 "8 Sale, maintenance and repair of morot vehicle and household goods" ///
		9 "9 Transport and communication" ///
		10 "10 Credit and insurance intermediation, land and housing rentals" ///
		11 "11 Public and personal services, household services" ///
		12 "12 Education, social and health-care facilities" ///
		13 "13 Public administration, social security"
label val w93 w93_de	
label var w93 "Sector categories for part-time correction procedure"
tab w93, m


* Part-time correction procedure in line with Fitzenberger and Seidlitz (2020)
*------------------------------------------------------------------------------
/* The original paper keeps (if applicable) more than one spell within the same 
year but weighs them according to the fraction of days worked in that year. 
I only keep the annual main spell, thus I will not use weights. The procedure 
is run separately for each gender. Instead of the years 2000-2011 I use 1985-2011. */

* Define p80 of the 2012 wage distribution for females (only full-time, logarithmized)
_pctile ln_wage_imp if year==2012 & frau==1 & teilzeit==0, p(80)
gen p80_2012=r(r1) // write it in every row (also those of males)
* Define p25 of the 2012 wage distribution for males (only full-time, logarithmized)
_pctile ln_wage_imp if year==2012 & frau==0 & teilzeit==0, p(25)
gen p25_2012=r(r1) if frau==0 // write it only in males' rows
* Dummy for lower end of the wage distribution in 2012
gen low_end=(ln_wage_imp<=p25_2012) if year==2012 & frau==0 & teilzeit==0
replace low_end=1 if ln_wage_imp<=p80_2012 & year==2012 & frau==1 & teilzeit==0 

* Define quantile_x = quantile of the full-time AND part-time distribution with
* the same wage as p25 of the full-time distribution (approx. p29 for men and p87 for women)
gen quantile_x=.
forvalue f=0/1{
	cumul ln_wage_imp if year==2012 & frau==`f', gen(a`f'2012)
	egen quantile_x`f'=max(a`f'2012) if low_end==1
	replace quantile_x=quantile_x`f' if frau==`f'
}
sort frau quantile_x
by frau: carryforward quantile_x, replace
drop quantile_x0 quantile_x1

* popprobit: Indicator for full-time and part-time spells used in Probit model (correction only if wage<=quantile_x)
gen popprobit2012=0
replace popprobit2012=1 if ((teilzeit==1 | teilzeit==0) &  a02012<=quantile_x & frau==0)
replace popprobit2012=1 if ((teilzeit==1 | teilzeit==0) &  a12012<=quantile_x & frau==1)
replace popprobit2012=0 if year!=2012

* theta: variable for the gap between own quantile and quantile_x
gen theta=.
forvalue f=0/1{
	gen d`f'2012=a`f'2012-quantile_x
	recode d`f'2012 (0/max=0)
	replace d`f'2012=abs(d`f'2012)
	replace theta=d`f'2012 if frau==`f' & year==2012
}

* Create theta and popprobit variables for 1985-2011 (original paper by S&F: 2000-2011)
forvalue y=1985/2011 {
	gen popprobit`y'=0
	forvalue f=0/1{
		cumul ln_wage_imp if year==`y' & frau==`f', gen(a`f'`y')
		replace popprobit`y'=1 if ((teilzeit==1 | teilzeit==0) &  a`f'`y'<=quantile_x )
		replace popprobit`y'=0 if year!=`y'
		gen d`f'`y'=a`f'`y'-quantile_x
		recode d`f'`y' (0/max=0)
		replace d`f'`y'=abs(d`f'`y')
		replace theta=d`f'`y' if frau==`f' & year==`y'
	}
}

* Part-time probit predictions
/* Part-time probit prediction for the respective year (tz_probit) AND part-time 
probit prediction for 2012 based on characteristics from the respective year 
(tz_probit2012). This way also individuals without observations in 2012 obtain
estimated probabilities. */
gen tz_probit2012=.
gen tz_probit=.

compress
save "$data/siab_preprobit.dta", replace 

set more off
forvalue f=0/1 {
	estimates clear 
	* Run probit for part-time work in 2012 and estimate coefficients using characteristics from 2012 (if popprobit2012==1)
	display "gender:`f', year: 2012"
	qui probit teilzeit theta age age2 i.educ i.berufcat i.w93 i.ao_bula if popprobit2012==1 & frau==`f'
	estimates store m2012 	
	* Predict part-time work probability in 2012 with the estimates from above (based on 2012 characteristics) but plugging in the characteristics of the respective year
	forvalue y=1985/2011{
		display "gender:`f', year: `y'"
		predict b`f'`y' if  popprobit`y'==1 & year==`y' & teilzeit==0 & frau==`f'
		replace tz_probit2012=b`f'`y' if  popprobit`y'==1 & year==`y' & teilzeit==0 & frau==`f'
	}
	forvalue y=1985/2011{
		* Run probit for part-time work in the respective year based on the corresponding characteristics from the same year (if popprobit`y'==1)
		display "gender:`f', year: `y'"
		qui probit teilzeit theta age age2 i.educ i.berufcat i.w93 i.ao_bula if popprobit`y'==1 & frau==`f'
		estimates store m`y'  
		* Predict part-time work probability in the respective year based on characteristics from the same year
		predict c`f'`y' if  popprobit`y'==1 & year==`y' & frau==`f'
		replace tz_probit=c`f'`y' if  popprobit`y'==1 & year==`y' & frau==`f'
	}
	estimates table m1985 m1990 m1995 m2000 m2005 m2010 m2011 m2012, 					///
		keep(theta age age2 1.educ 2.educ 3.educ) 	///
			nostar b(%8.3f) t(%8.1f) 
}


* Create full-time weights
*--------------------------
/* Weighting scheme:
o	We weight official part-time spells (those reported as part-time even in 
	years before 2012) by 0.5.
o	The new reporting system was fully operative in 2012 so we don't need to 
	reweight full-time spells in 2012 or thereafter. They will receive a weight 
	of 1.
o	Full-time spells with a wage larger than quantile_x (= quantile of the 
	full-time AND part-time distribution with the same wage as p25 of the 
	full-time distribution (approx. p29 for men and p87 for women).) will also 
	receive a weight of 1. -> if popprobit`y'==0
o	Reweight full-time spells in the respective year if popprobit`y'==1 using 
	the ratio of the predicted probabilities of being reported to work full-time 
	in 2012 and year t. According to Seidlitz and Fitzenberger (2019) the "goal 
	is to downweight full-time spells in year t which given their characteristics 
	have a lower full-time probability in 2012 than the probability of being 
	reported full-time in year t." */
gen weight=1 
* Set full-time weight of "true" part-time spells equal to 0.5 (if teilzeit==1) for all years
forvalue y=1985/2017{
	replace weight=0.5 if year==`y' & teilzeit==1
}
* Adjust full-time weights if necessary
forvalue y=1985/2011{
	replace weight=((1-tz_probit2012)/(1-tz_probit)) if popprobit`y'==1 & year==`y' & teilzeit==0
}
* Censor weight at 1 if it exceeds 1
gen weight_cap=weight
recode weight_cap (1/max=1)
drop weight
rename weight_cap weight

* Label weight variable
label var weight "Full-time job equivalence weight"

* Summary statistics for weight variable (right censored at 1)
sum weight

* Drop variables no longer needed
drop berufcat p80_2012-c12011 

* Erase temporary data set
erase "$data/siab_preprobit.dta" 


* Create combined weight
*-----------------------
gen days=endepi-begepi+1 // spell duration regardless of employment or unemployment
gen schalt=0
forvalue x=1976(4)2012{
        replace schalt=1 if year==`x' 
}
gen daysfrac=days/365 if schalt==0
replace daysfrac=days/366 if schalt==1
gen weight_duration_ft=daysfrac*weight
label var weight_duration_ft "Duration and full-time weight"

* Save data set
*--------------
save "${data}/siab_clean_west.dta", replace 





log close


