capture log close
log using "${log}/19_occ_harmonization.log", replace

*______________________________________________________________________________
*
* 19_occ_harmonization.do	
*
* Author: Michelle Hansch
*
* This do-file tackles the structural breaks in the KldB 1988 occupation
* variable (beruf) after 2010. It implements the harmonization algorithm 
* suggested in the FDZ Method Report "Smoothing the Turmoil: Harmonization   
* of the 1988 Occupation Codes over Time" by Michelle Hansch.
*
* The harmonization algorithm implements the following:
* 1)	It refines the official correspondence between the 2010 and 1988 
*		classifications of the Federal Employment Agency, already 
*		implemented in the SIAB data, by reassigning 5-digit 2010 occupation 
*		codes to more suitable 3-digit 1988 occupation codes after 2010.
* 2)	It aggregates 1988 occupations with severe structural breaks of more 
*		than 0.5 percentage points between 2010 and 2012.
* 3)	It aggregates 1988 occupations with zero employment shares after 2010. 
* 4)	It tags the 1988 occupations that still exhibit structural breaks even
*		after the harmonization algorithm has been implemented.
*
*______________________________________________________________________________


use "${data}/employment_data.dta", clear
destring beruf2010_5, replace force

* Redefine labels for modified occupations
label copy beruf_en  beruf_redefined
label values beruf beruf_redefined
label var beruf "Modified KldB 1988 occupation codes"

* Create dummy for modified occupations
gen modified_occ=0
label var modified_occ "(1) KldB 1988 occupation code was modified (aggregated or reassigned) or not (0)"	

* 1) Reassign KldB 2010 occupation codes to selected KldB 1988 occupation codes 
*------------------------------------------------------------------------------

	* 781-783 office specialists, stenographers, typists (modified)
	*--------------------------------------------------------------
	replace beruf=781 if (beruf!=781 & year >2010 &  (beruf2010_5==51623 | beruf2010_5==51624 | ///
			beruf2010_5==61112 | beruf2010_5==61194 | beruf2010_5==61213 | beruf2010_5==61283 | ///
			beruf2010_5==61313 | beruf2010_5==71303 | beruf2010_5==71393 | beruf2010_5==71514 | ///
			beruf2010_5==71522 | beruf2010_5==72212 | beruf2010_5==72294 | beruf2010_5==73201 | ///
			beruf2010_5==73222 | beruf2010_5==92122 | beruf2010_5==92113 | beruf2010_5==92133)) 
	replace modified_occ=1 if beruf==781
	// label defined below
	
	* 270-275 Locksmiths (modified)
	*------------------------------
	replace beruf=270 if (beruf!=270 & year >2010 & (beruf2010_5==25132))
	replace modified_occ=1 if beruf==270
	// label defined below

	* 285, 311-315, 321-323 Other mechanics, electricians, assemblers, metal workers (modified)
	*------------------------------------------------------------------------------------------
	replace beruf=285 if (beruf!=285 & year >2010 &  (beruf2010_5==24201 | beruf2010_5==24202))
	replace modified_occ=1 if beruf==285
	// label defined below

	* 712 Railway controllers, conductors (modified)
	*-----------------------------------------------
	replace beruf=712 if (beruf!=712 & year >2010 &  beruf2010_5==51593  )
	replace modified_occ=1 if beruf==712
	label 	def beruf_redefined 712 "712 Railway controllers, conductors (modified)", modify 	
	
	* 856 Medical receptionists (modified)
	*-------------------------------------
	replace beruf=856 if (beruf!=856 & year >2010 &  beruf2010_5==73223 )
	replace modified_occ=1 if beruf==856
	label 	def beruf_redefined 856 "856 Medical receptionists (modified)", modify 

	* 861-862 Social/care workers, home wardens (modified)
	*-----------------------------------------------------
	replace beruf=861 if (beruf!=861 & year >2010 & beruf2010_5==83193)
	replace modified_occ=1 if beruf==861
	// label defined below
	
	* 922 Consumer advisors (modified)
	*---------------------------------
	replace beruf=922 if (beruf!=922 & year >2010 &  beruf2010_5==42313)
	replace modified_occ=1 if beruf==922
	label 	def beruf_redefined 922 "922 Consumer advisors (modified)", modify 

* 2) Aggregate (3-digits) KldB 1988 occupations with severe structural breaks in 2010 
*-------------------------------------------------------------------------------------
	replace beruf=11 if (beruf==21 | beruf==41 | beruf==42 | beruf==43 | beruf==44)
	replace modified_occ=1 if beruf==11
	label 	def beruf_redefined 11 "11, 21, 41-44 Farmers, land workers, animal breeders/keepers", modify 
 
	replace beruf=270 if (beruf==271 | beruf==272 | beruf==273 | beruf==274 | beruf==275) 
	replace modified_occ=1 if beruf==270	
	label 	def beruf_redefined 270 "270-275 Locksmiths (modified)", modify 	

	replace beruf=285 if (beruf==311 | beruf==312 | beruf==313 | beruf==314 | beruf==315 | beruf==321 | beruf==322 | beruf==323)
	replace modified_occ=1 if beruf==285
	label 	def beruf_redefined 285 "285, 311-315, 321-323 Other mechanics, electricians, assemblers, metal workers (modified)", modify 	

	replace beruf=391 if (beruf==392 | beruf==401 | beruf==402 | beruf==431 | beruf==432 | beruf==433)
	replace modified_occ=1 if beruf==391
	label 	def beruf_redefined	391 "391-402, 431-433 Bakery goods/meat/other food processors", modify 

	replace beruf=522 if (beruf==741 | beruf==744) 	
	replace modified_occ=1 if beruf==522
	label 	def beruf_redefined 522 "522, 741, 744 Packagers, warehousemen, transport workers", modify 	

	replace beruf=544 if (beruf==545 | beruf==546)
	replace modified_occ=1 if beruf==544
	label 	def beruf_redefined 544 "544-546 Construction machine drivers/attendants", modify 	

	replace beruf=601 if (beruf==602 | beruf==606 | beruf==607)
	replace modified_occ=1 if beruf==601
	label 	def beruf_redefined 601 "601-602, 606-607 Mechanical/electrical/other engineers", modify 

	replace beruf=603 if (beruf==604 | beruf==605)
	replace modified_occ=1 if beruf==603
	label 	def beruf_redefined 603 "603-605 Architects, civil/survey/mining engineers", modify 	

	replace beruf=621 if (beruf==622 | beruf==628 | beruf==629 | beruf==635)
	replace modified_occ=1 if beruf==621
	label 	def beruf_redefined 621 "621-622, 628-629, 635 Mechanical/electrical/other technicians, technical draughtspersons", modify 	

	replace beruf=633 if beruf==634
	replace modified_occ=1 if beruf==633
	label 	def beruf_redefined 633 "633-634 Chemical/photo laboratory assistants", modify 	

	replace beruf=684 if (beruf==685 | beruf==844)
	replace modified_occ=1 if beruf==684
	label 	def beruf_redefined 684 "684-685, 844 Druggists, pharmacy aids, pharmacists", modify 	

	replace beruf=731 if (beruf==732 | beruf==733 | beruf==734) 
	replace modified_occ=1 if beruf==731
	label 	def beruf_redefined 731 "731-734 Communication occupations", modify 	

	replace beruf=771 if (beruf==772)
	replace modified_occ=1 if beruf==771
	label 	def beruf_redefined 771 "771-772 (Cost) accountants, valuers", modify 
	
	replace beruf=781 if (beruf==782 | beruf==783)
	replace modified_occ=1 if beruf==781
	label 	def beruf_redefined 781 "781-783 Office specialists, stenographers, typists (modified)", modify 
	
	replace beruf=855 if beruf==857
	replace modified_occ=1 if beruf==857
	label 	def beruf_redefined 855 "855, 857 Dietary/pharmaceutical/medical laboratory assistants", modify 	

	replace beruf=861 if beruf==862
	replace modified_occ=1 if beruf==862
	label 	def beruf_redefined 861 "861-862 Social/care workers, home wardens (modified)", modify 	
	
	replace beruf=912 if beruf==913
	replace modified_occ=1 if beruf==913
	label 	def beruf_redefined 912 "912-913 Waiters, stewards, others attending on guests", modify 
		
	replace beruf=911 if beruf==921
	replace modified_occ=1 if beruf==921
	label 	def beruf_redefined 911 "911, 921 Restaurant/bar keepers, hotel proprietors, housekeeping managers", modify 

	replace beruf=934 if beruf==937
	replace modified_occ=1 if beruf==937
	label 	def beruf_redefined 934 "934, 937 Glass/building/machinery/container cleaners", modify 
	
	
* 3) Aggregation of occupations with zero-employment shares:
*-----------------------------------------------------------
	replace beruf=71 if (beruf==72 | beruf==81 | beruf==82 | beruf==83)
	replace modified_occ=1 if beruf==71
	label 	def beruf_redefined	71 "71-83 Miners, mineral/oil/gas quarries", modify 

	replace beruf=91 if (beruf==101 | beruf==102)
	replace modified_occ=1 if beruf==91
	label 	def beruf_redefined	91 "91-102 Mineral/stone preparers", modify 

	replace beruf=111 if (beruf==112)
	replace modified_occ=1 if beruf==111
	label 	def beruf_redefined	111 "111-112 Building material makers", modify 

	replace beruf=131 if (beruf==132 | beruf==133 | beruf==134 | beruf==135)
	replace modified_occ=1 if beruf==131
	label 	def beruf_redefined	131 "131-135 Glass makers", modify 

	replace beruf=141 if (beruf==142 | beruf==143 | beruf==144)
	replace modified_occ=1 if beruf==141
	label 	def beruf_redefined	141 "141-144 Chemical workers", modify 

	replace beruf=161 if (beruf==162 | beruf==163 | beruf==164)
	replace modified_occ=1 if beruf==161
	label 	def beruf_redefined	161 "161-164 Paper makers", modify 

	replace beruf=171 if (beruf==172)
	replace modified_occ=1 if beruf==171
	label 	def beruf_redefined	171 "171-172 Type setters, printed goods makers", modify 

	replace beruf=173 if (beruf==174 | beruf==175)
	replace modified_occ=1 if beruf==173
	label 	def beruf_redefined	173 "173-175 Printers, screeners", modify 

	replace beruf=176 if (beruf==177)
	replace modified_occ=1 if beruf==176
	label 	def beruf_redefined	176 "176-177 Copiers, printer's assistants", modify 

	replace beruf=181 if (beruf==182 | beruf==183 | beruf==184)
	replace modified_occ=1 if beruf==181
	label 	def beruf_redefined	181 "181-184 Wood preparers/moulders/product makers", modify  

	replace beruf=192 if (beruf==193 | beruf==211 | beruf==212 | beruf==213)
	replace modified_occ=1 if beruf==192
	label 	def beruf_redefined	192 "192-193, 211-213 Metal rollers/drawers/moulders (non-cutting deformation)", modify 
	
	replace beruf=201 if  (beruf==202 | beruf==203)
	replace modified_occ=1 if beruf==201
	label 	def beruf_redefined	201 "201-203 Moulders, mould casters", modify 

	replace beruf=221 if (beruf==222 | beruf==223 | beruf==224 | beruf==225 | beruf==226)
	replace modified_occ=1 if beruf==221
	label 	def beruf_redefined	221 "221-226 Metal moulders (metal-cutting deformation)", modify 

	replace beruf=231 if (beruf==232 | beruf==233 | beruf==234 | beruf==235)
	replace modified_occ=1 if beruf==231
	label 	def beruf_redefined	231 "231-235 Metal surface processors and finishers", modify 

	replace beruf=241 if (beruf==242 | beruf==243 | beruf==244)
	replace modified_occ=1 if beruf==241
	label 	def beruf_redefined	241 "241-244 Metal connectors", modify 

	replace beruf=251 if (beruf==252)
	replace modified_occ=1 if beruf==251
	label 	def beruf_redefined	251 "251-252 Smiths", modify 

	replace beruf=301 if (beruf==302)
	replace modified_occ=1 if beruf==301
	label 	def beruf_redefined	301 "301-302 Precision fitters, precious metal smiths", modify 

	replace beruf=331 if (beruf==332)
	replace modified_occ=1 if beruf==331
	label 	def beruf_redefined	331 "331-332 Spinners", modify 

	replace beruf=341 if (beruf==342 | beruf==343 | beruf==344 | beruf==345 | beruf==346)
	replace modified_occ=1 if beruf==341
	label 	def beruf_redefined	341 "341-346 Textile makers", modify 

	replace beruf=351 if (beruf==352 | beruf==353 | beruf==354 | beruf==355 | beruf==356 | beruf==357)
	replace modified_occ=1 if beruf==351	
	label 	def beruf_redefined	351 "351-357 Textile processors", modify 

	replace beruf=361 if (beruf==362)
	replace modified_occ=1 if beruf==361
	label 	def beruf_redefined	361 "361-362 Textile finisher", modify 

	replace beruf=372 if (beruf==373)
	replace modified_occ=1 if beruf==372
	label 	def beruf_redefined	372 "372-373 Shoe/footwear makers", modify 

	replace beruf=374 if (beruf==375)
	replace modified_occ=1 if beruf==374
	label 	def beruf_redefined	374 "374-375 Coarse/fine leather goods makers", modify 

	replace beruf=376 if (beruf==377)
	replace modified_occ=1 if beruf==376
	label 	def beruf_redefined	376 "376-377 leather clothing makers, glovemakers", modify 

	replace beruf=421 if (beruf==422)
	replace modified_occ=1 if beruf==421
	label 	def beruf_redefined	421 "421-422 Wine coopers, brewers", modify  

	replace beruf=470 if (beruf==471 | beruf==472)
	replace modified_occ=1 if beruf==470
	label 	def beruf_redefined	470 "470-472 Building labourers/assistants", modify 

	replace beruf=541 if (beruf==542)
	replace modified_occ=1 if beruf==541	
	label 	def beruf_redefined	541 "541-542 Generator/aerial ropeway machinists", modify 

	replace beruf=547 if (beruf==548)
	replace modified_occ=1 if beruf==547
	label 	def beruf_redefined	547 "547-548 Machine attendants, stokers", modify 

	replace beruf=682 if (beruf==686)
	replace modified_occ=1 if beruf==682	
	label 	def beruf_redefined	682 "682, 686 Salespersons, service-station attendants", modify 
  
	replace beruf=688  if  (beruf==706 | beruf==773)
	replace modified_occ=1 if beruf==688	
	label 	def beruf_redefined 688 "688, 706, 773 Mobile traders, cashiers, ticket sellers/inspectors", modify 	

	replace beruf=691 if (beruf==692 | beruf==693 | beruf==694)
	replace modified_occ=1 if beruf==691	
	label 	def beruf_redefined	691 "691-694 Bank/building society/insurance specialists", modify 

	replace beruf=723 if (beruf==724)
	replace modified_occ=1 if beruf==723	
	label 	def beruf_redefined	723 "723-724 Deck seamen, inland boatmen", modify 

	replace beruf=791 if (beruf==792)
	replace modified_occ=1 if beruf==791
	label 	def beruf_redefined	791 "791-792 Detectives, watchmen", modify 

	replace beruf=811 if (beruf==812 | beruf==813)
	replace modified_occ=1 if beruf==811
	label 	def beruf_redefined	811 "811-813 Arbitrators, judical administrators, legal advisors", modify 

	replace beruf=853 if (beruf==888)
	replace modified_occ=1 if beruf==853	
	label 	def beruf_redefined	853 "853, 888 Nurses, midwives, nursing staff", modify 

	replace beruf=872 if (beruf==873)
	replace modified_occ=1 if beruf==872
	label 	def beruf_redefined	872 "872-873 Primary/secondary/tertiary/special school teachers", modify 

	replace beruf=931 if (beruf==932)
	replace modified_occ=1 if beruf==931
	label 	def beruf_redefined	931 "931-932 Laundry workers, textile cleaners, dyers", modify 

* 4) Highlight remaining occupations with structural breaks 
*----------------------------------------------------------
gen problematic_occ=0
* Tag remaining occupations with structural breaks in West Germany
replace problematic_occ=1 if east==0 & (beruf==151 | beruf==285 | beruf==470 | ///
		beruf==522 | beruf==531 | beruf==543 | beruf==687 | beruf==751 | beruf==771 | ///
		beruf==791 | beruf==854 | beruf==863 | beruf==871 | beruf==883) 
* Tag remaining occupations with structural breaks in East Germany
replace problematic_occ=1 if east==1 & (beruf==151 | beruf==470 | beruf==522 | ///
		beruf==531 | beruf==543 | beruf==687 | beruf==703 | beruf==731 | beruf==751 | ///
		beruf==762 | beruf==771 | beruf==791 | beruf==794 | beruf==854 | beruf==863 | ///
		beruf==871 | beruf==877 | beruf==883) 
label var problematic_occ "Remaining occupations with structural break after 2010 (separately for East/West)"

* Summary statistics
*-------------------
tab modified_occ, m
tab problematic_occ, m
tab beruf, m

* Save data set
compress
save "${data}/post_harmonization.dta", replace

log close




