/*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	
	Master Do-File for the SIAB 7517 Preparation (including Modifications), 
	Part-time Correction, and Harmonization of the 1988 Occupation Codes.

	Project ID: 1806
	Author: Michelle Hansch
	Created: 2025-03-27
	
	Note: 
	The original do-file is part of the Stata do-file collection offered as a 
	supplement to Stüber, Dauth, and Eppelsheimer (2023): A Guide to Preparing 
	the Sample of Integrated Labour Market Biographies (SIAB, version 7519 v1) 
	for Scientific Analysis. Journal for Labour Market Research, 57:7.
	https://doi.org/10.1186/s12651-023-00335-w
	
	It was extended to include the part-time correction by Fitzenberger and 
	Seidlitz (2020), as well as the harmonization of the 1988 occupation codes 
	by Michelle Hansch (2025).

	Original do-files by Stüber, Dauth, and Eppelsheimer (2023) that have been 
	modified are marked with 'MODIFIED' in their filenames.  Files not required 
	for the occupational harmonization have been commented out."

~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~*/


********************************************************************************
********************************************************************************
* Set up your working directory when working with SUF or at the IAB
********************************************************************************
/*
* Do NOT remove this comment when working on-site at the FDZ or via remote access!

* In the line below, replace XYZ with YOUR working directory (example: cd "P:\my_project\stata\")
cd "XYZ"

* Run the following 4 lines of code to create the subfolders "prog", "log", "orig", and "data" in your working directory.
shell mkdir prog
shell mkdir log
shell mkdir data
shell mkdir orig

* Copy original data (e.g, the SIAB SUF) into the subfolder "orig".
* Copy this do-file and all other provided do-files in the subfolder "prog".

* The following lines define global variables, analogous to the FDZ setting
global prog = "prog" // folder for do-files
global log  = "log"  // folder for log-files and graphs
global orig = "orig" // folder for original datasets
global data = "data" // your data folder

*/
********************************************************************************
********************************************************************************

/*
capture log close
global logfile = 1 // set global to 0 if you do not want to open the following log-file
if(${logfile}==1) log using "$log/00_master_SIAB.log", replace
dis "$S_DATE $S_TIME"
*/

********************************************************************************
* Load SIAB and set observation period
********************************************************************************
version 17 // version used at FDZ
clear all
set more off

set linesize 120 // Max. line size JoSuA Internal Use
//set linesize 255 // Max. line size 

* set observation period
global minYear = 1985 // begin of your observation period (default: 1975)
global maxYear = 2017 // end of your observation period (default: 2019)

* Enables/disables certain outputs (tables and figures) to inspect the data
global inspect = 0 // default: 0; set to 1, to generate certain outputs (tables and figures) to inspect the data. In JoSuA presentation/publication mode, please leave the default setting to reduce the outputs that need to be reviewed by the FDZ as part of the data protection review.

use "${orig}/SIAB_7517_v1.dta", clear


********************************************************************************
* Restrict sources and generate variables 'jahr' (year) and age
********************************************************************************
* Limit sources to periods of employment and periods of benefit receipt
if(${inspect}==1) tab quelle, m
keep if inlist(quelle,1,2,3)
/*
* Remove all variables that contain only missings
foreach var of varlist _all {
	capture assert missing(`var')
	if !_rc {
		drop `var'
	}
}
*/
* Generate variable 'jahr' (year) 
gen int jahr = year(begepi)
label language de
label variable jahr "Jahr"
label language en
label variable jahr "year"

* Generate variable age
gen age = jahr - gebjahr
label language de
label variable age "Alter (in Jahren)"
label language en
label variable age "age (in years)"

//capture log close


********************************************************************************
* 01) Split episodes that span over one year
********************************************************************************
* The do-file can be omitted if SIAB is restricted to employment periods only ("keep if inlist(source,1)" in line 74 instead of "keep if inlist(source,1,2,3)").
global logfile = 1 // set global to 0 if you do not want log the following do-file
do "${prog}/01_split_episodes.do"


********************************************************************************
* 02) Reallocation of wages from spells with deregistration reason 154 to employment spells
********************************************************************************
// irrelevant for SIAB 7517.
/*
* The do-file can be omitted. However, we recommend that you run it.
global logfile = 1 // set global to 0 if you do not want log the following do-file
do "${prog}/02_grund154.do"
*/

********************************************************************************
* 03) Generate biographical variables (tage_erw, tage_bet, ...)
* ... by using a slightly modified version of the do-file '01_SIAB_bio.do' from 
*	  FDZ-Methodenreport 05/2021 (P. vom Gerge & A. Schmucker).
********************************************************************************
* The do-file should not be omitted as it is needed for the wage imputation.
global logfile = 1 // set global to 0 if you do not want log the following do-file
do "${prog}/03_SIAB_bio_MODIFIED.do"


********************************************************************************
* Restrict data set to observation period
********************************************************************************
if(${inspect}==1) su jahr
keep if inrange(jahr,${minYear},${maxYear})


********************************************************************************
* 04) Merge basic BHP data
********************************************************************************
* The do-file should not be omitted as it is, inter alia, needed to generate the 
* east dummy for the wage imputation. This do-file merges only basic BHP variables 
* to the SIAB. Further BHP variables can be merged to the SIAB using 11_merge_BHP.do.
global logfile = 1 // set global to 0 if you do not want log the following do-file
do "${prog}/04_merge_basic_BHP_MODIFIED.do"


********************************************************************************
* 05) Create broader education groups
********************************************************************************
* The do-file should not be omitted as it is needed for the wage imputation.
global logfile = 1 // set global to 0 if you do not want log the following do-file
do "${prog}/05_educ_broad_MODIFIED.do"


********************************************************************************
* 06) Add the contribution assessment ceiling
********************************************************************************
* The do-file should not be omitted as it is needed for the wage imputation.
global logfile = 1 // set global to 0 if you do not want log the following do-file
do "${prog}/06_wages_assessment_ceiling.do"


********************************************************************************
* 07) Add the marginal part-time income threshold and flag marginal wages
********************************************************************************
* The do-file should not be omitted as it is needed for the wage imputation.
global logfile = 1 // set global to 0 if you do not want log the following do-file
do "${prog}/07_wages_marginal.do"


********************************************************************************
* 08) Deflate wages, marginal part-time income threshold and contribution assessment ceiling
********************************************************************************
* The do-file should not be omitted as it is needed for the wage imputation.
global logfile = 1 // set global to 0 if you do not want log the following do-file
do "${prog}/08_wages_deflation.do"

save "${data}/siab_deflated.dta", replace 
use "${data}/siab_deflated.dta", clear

*_______________________________________________________________________________ 
*
* 09) Impute missing values and restrict the data to certain groups
*_______________________________________________________________________________ 
* The do-files should not be omitted as it is needed for the wage imputation
* and the occupational harmonization.
global logfile = 1 // set global to 0 if you do not want log the following do-file
do "${prog}/09a_impute_missings.do"
do "${prog}/09b_restrictions.do"

********************************************************************************
* 10) Impute wages (2-step procedure, based on Dustmann et al. (2009) and Card et al. (2013))
********************************************************************************
* The do-file should not be omitted unless you are not interested in wages or only wanted to analyze employment relationships with uncensored wages.
global logfile = 1 // set global to 0 if you do not want log the following do-file
do "${prog}/10_wages_imputation_MODIFIED.do"

save "${data}/siab_wages_imputed.dta", replace


********************************************************************************
* 11) Merge further BHP data to SIAB
********************************************************************************
* The following steps are omitted by default since additional data access must be requested. To conduct these steps, activate the global macros.
/*
global annual_BHP = 0  // default = 0; change to 1 to merge additional variable blocks and sensitive BHP variables (must be requested) 
global BHP_inflow = 0  // default = 0; change to 1 to merge inflow information from extension file "Worker flows" (extension file "Worker flows" must be requested)
global BHP_outflow = 0 // default = 0; change to 1 to merge outflow information from extension file "Worker flows" (extension file "Worker flows" must be requested)
global BHP_entry = 0   // default = 0; change to 1 to merge entry information from extension file "Entry and exits" (extension file "Entry and exits" must be requested)
global BHP_exit = 0    // default = 0; change to 1 to merge exit information from extension file "Entry and exits" (extension file "Entry and exits" must be requested)
global logfile = 1 // set global to 0 if you do not want log the following do-file
if(${annual_BHP}==1 | ${BHP_inflow}==1 | ${BHP_outflow}==1 | ${BHP_entry}==1 | ${BHP_exit}==1) do ${prog}\11_merge_BHP.do


********************************************************************************
* 12) Merge person and establishment fixed effects (AKM)
********************************************************************************
* The following steps are omitted by default since additional data access must be requested. To conduct these steps, activate the global macros.
global AKM_estab = 0 // deflaut = 0; change to 1 to merge establishment fixed effects (AKM effects must be requested)
global AKM_pers = 0  // deflaut = 0; change to 1 to merge person fixed effects (AKM effects must be requested)
global logfile = 1 // set global to 0 if you do not want log the following do-file
if(${AKM_estab}==1 | ${AKM_pers}==1) do ${prog}\12_merge_AKM.do


********************************************************************************
*  13) Map 3-digit industries to 1-digit industries based on... 
* ... 'Statistisches Bundesamt' (destatis) and/or 
* ... IAB establishment panel (estpanel)
********************************************************************************
* The following steps are omitted by default. To conduct these steps, activate the global macros.
global destatis = 0 // default = 0; change to 1 to generate mapping based on 'Statistisches Bundesamt' (2002)
global estpanel = 0 // default = 0; change 1 to generate mapping based on IAB establishment panel
global logfile = 1 // set global to 0 if you do not want log the following do-file
if(${destatis}==1 | ${estpanel}==1) do ${prog}\13_industries_1digit.do


********************************************************************************
* 14) Add Blossfeld occupations
********************************************************************************
* The following step is omitted by default. To conduct this step, activate the global macros.
global blossfeld = 0 // default = 0; change to 1 to generate the occupational classification of Blossfeld
global logfile = 1 // set global to 0 if you do not want log the following do-file
if(${blossfeld}==1) do ${prog}\14_occ_blossfeld.do
*/

********************************************************************************
* 15) Treat parallel episodes:
* Generate information on parallel episodes
* Keep only 'main' episode
********************************************************************************
* The do-file must not be omitted if you are interested in the aggregated (employment) outcomes generated in 16_yearly_panel.do. In this case, you must ensure that 09_restriction.do does not delete all data that does not exist on the cutoff date.
* The do-file must be omitted if parallel spells are to be retained. In this case, you must ensure that 09_restriction.do does not delete all data that does not exist on the cutoff date.
* The do-file must be omitted if you want to create a yearly panel with all observations that exist on the cutoff date, not just the 'main' episode. In this case, you must ensure that 09_restriction.do does not delete all data that does not exist on the cutoff date.
global parallel_vars = 0 // default == 0; set to 1 to generate information on parallel jobs
global logfile = 1 // set global to 0 if you do not want log the following do-file
do "${prog}/15_parallel_episodes.do"


********************************************************************************
* 16) Transfer data set into annual panel
********************************************************************************
* The do-file can be omitted if no annual panel is to be created.
global yearly_vars = 0 // default == 0; set to 1 to generate aggregate (employment) outcomes
global cutoffMonth = 6 // default: Month = 6 == June; set month of cutoff date
global cutoffDay = 30  // default: Day = 30; set day of cutoff date
global logfile = 1 // set global to 0 if you do not want log the following do-file
do "${prog}/16_yearly_panel.do"


********************************************************************************
* 17) Clean up
********************************************************************************
* The do-file can be omitted. However, we recommend that you run it.
* Note: The default settings in siab_clean.dta assume that an annual panel was generated.
global logfile = 1 // set global to 0 if you do not want log the following do-file
do "${prog}/17_clean_up.do"


********************************************************************************
* Choose label language
********************************************************************************
label language en // English labels
*label language de // German labels 


********************************************************************************
* Save data
********************************************************************************
save "${data}/siab_clean.dta", replace


*_______________________________________________________________________________ 
*
* Part-time correction procedure following Fitzenberger and Seidlitz (2020)
*_______________________________________________________________________________ 
do "${prog}/18a_parttime_correction_east.do"
do "${prog}/18b_parttime_correction_west.do"
do "${prog}/18c_parttime_correction_combine.do"

* Save data set
compress
save "${data}/employment_data.dta", replace 
use "${data}/employment_data.dta", clear

*_______________________________________________________________________________
*
* Harmonization of the 1988 occupation codes
*_______________________________________________________________________________ 
do "${prog}/19_occ_harmonization.do"


********************************************************************************
* Write file list in log-file
********************************************************************************
/*
capture log close
log using "$log/filelist_prep.log", replace
dir $prog/
dir $log/
dir $data/
dir $orig/
dis "$S_DATE $S_TIME"
*/

cap log close
